@@ -4,7 +4,6 @@
 #' Perform `mclust::Mclust` clustering for multivariate GMM
 #'
 #' @param sessions tibble, sessions data set in evprof
-#' [standard format](https://mcanigueral.github.io/evprof/articles/sessions-format.html).
 #' @param k number of clusters
 #' @param mclust_tol tolerance parameter for clustering
 #' @param mclust_itmax maximum number of iterations
@@ -18,7 +17,8 @@
 #' @importFrom mclust Mclust emControl
 #'
 get_connection_model_mclust_object <- function(sessions, k, mclust_tol = 1e-8, mclust_itmax = 1e4,
-                                               log = FALSE, start = getOption("evprof.start.hour")) {
+                                               log = getOption("evprof.log", FALSE),
+                                               start = getOption("evprof.start.hour")) {
   if (!log) {
     sessions["ConnectionStartDateTime"] <- convert_time_dt_to_plot_num(
       sessions[["ConnectionStartDateTime"]],
@@ -60,8 +60,7 @@ get_connection_model_params <- function(mclust_obj) {
 #' the stronger the evidence for the model and number of clusters
 #' (see, e.g. Fraley and Raftery 2002a).
 #'
-#' @param sessions tibble, sessions data set in evprof
-#' [standard format](https://mcanigueral.github.io/evprof/articles/sessions-format.html).
+#' @param sessions tibble, sessions data set in evprof standard format
 #' @param k sequence with the number of clusters, for example 1:10, for 1 to 10 clusters.
 #' @param mclust_tol tolerance parameter for clustering
 #' @param mclust_itmax maximum number of iterations
@@ -82,7 +81,8 @@ get_connection_model_params <- function(mclust_obj) {
 #'
 #'
 choose_k_GMM <- function(sessions, k, mclust_tol = 1e-8, mclust_itmax = 1e4,
-                         log = FALSE, start = getOption("evprof.start.hour")) {
+                         log = getOption("evprof.log", FALSE),
+                         start = getOption("evprof.start.hour")) {
   mod <- get_connection_model_mclust_object(
     sessions, k = k, mclust_tol = mclust_tol,
     mclust_itmax = mclust_itmax, log = log, start = start
@@ -93,8 +93,7 @@ choose_k_GMM <- function(sessions, k, mclust_tol = 1e-8, mclust_itmax = 1e4,
 
 #' Cluster sessions with `mclust` package
 #'
-#' @param sessions tibble, sessions data set in evprof
-#' [standard format](https://mcanigueral.github.io/evprof/articles/sessions-format.html).
+#' @param sessions tibble, sessions data set in evprof standard format
 #' @param k number of clusters
 #' @param seed random seed
 #' @param mclust_tol tolerance parameter for clustering
@@ -136,7 +135,8 @@ choose_k_GMM <- function(sessions, k, mclust_tol = 1e-8, mclust_itmax = 1e4,
 #'   ggplot2::aes(color = Cluster)
 #'
 cluster_sessions <- function(sessions, k, seed, mclust_tol = 1e-8, mclust_itmax = 1e4,
-                             log = FALSE, start = getOption("evprof.start.hour")) {
+                             log = getOption("evprof.log", FALSE),
+                             start = getOption("evprof.start.hour")) {
   set.seed(seed)
   mclust_obj <- get_connection_model_mclust_object(
     sessions, k, mclust_tol = mclust_tol, mclust_itmax = mclust_itmax,
@@ -152,8 +152,7 @@ cluster_sessions <- function(sessions, k, seed, mclust_tol = 1e-8, mclust_itmax
 
 #' Save iteration plots in PDF file
 #'
-#' @param sessions tibble, sessions data set in evprof
-#' [standard format](https://mcanigueral.github.io/evprof/articles/sessions-format.html).
+#' @param sessions tibble, sessions data set in evprof standard format
 #' @param k number of clusters
 #' @param filename string defining the PDF output file path (with extension .pdf)
 #' @param it number of iterations
@@ -180,11 +179,12 @@ cluster_sessions <- function(sessions, k, seed, mclust_tol = 1e-8, mclust_itmax
 #' }
 #'
 #'
-save_clustering_iterations <- function(sessions, k, filename, it=12,
+save_clustering_iterations <- function(sessions, k, filename, it=6,
                                        seeds = round(runif(it, min=1, max=1000)),
                                        plot_scale = 2, points_size = 0.25,
                                        mclust_tol = 1e-8, mclust_itmax = 1e4,
-                                       log = FALSE, start = getOption("evprof.start.hour")) {
+                                       log = getOption("evprof.log", FALSE),
+                                       start = getOption("evprof.start.hour")) {
   ellipses_plots <- list()
   IC_values <- tibble(
     seed = seeds,
@@ -233,8 +233,7 @@ get_ellipse <- function(mu, sigma, alpha = 0.05, npoints = 200) {
 
 #' Plot Bivariate Gaussian Mixture Models
 #'
-#' @param sessions tibble, sessions data set in evprof
-#' [standard format](https://mcanigueral.github.io/evprof/articles/sessions-format.html).
+#' @param sessions tibble, sessions data set in evprof standard format
 #' @param models tibble, parameters of the clusters' GMM models obtained with
 #' function `cluster_sessions` (object `models` of the returned list)
 #' @param profiles_names names of profiles
@@ -285,7 +284,8 @@ get_ellipse <- function(mu, sigma, alpha = 0.05, npoints = 200) {
 #'
 plot_bivarGMM <- function(sessions, models, profiles_names = seq(1, nrow(models)),
                           points_size = 0.25, lines_size = 1, legend_nrow = 2,
-                          log = FALSE, start = getOption("evprof.start.hour")) {
+                          log = getOption("evprof.log", FALSE),
+                          start = getOption("evprof.start.hour")) {
   ellipses <- purrr::map_dfr(
     set_names(seq(1, nrow(models)), nm = profiles_names),
     ~ get_ellipse(models$mu[[.x]], models$sigma[[.x]]),
@@ -313,4 +313,3 @@ plot_bivarGMM <- function(sessions, models, profiles_names = seq(1, nrow(models)
   }
   return( plot )
 }
-
